from flask import session, request, redirect, url_for, flash
from functools import wraps


def login_required(show_warning=True):
    def wrapper(f):
        @wraps(f)
        def decorated_function(*args, **kwargs):
            if not check_is_logged_in():
                if show_warning:
                    flash('Für diese Aktion musst du eingeloggt sein!', 'danger')
                return redirect(url_for('login.login', next=request.url))
            return f(*args, **kwargs)
        return decorated_function
    return wrapper


def check_is_logged_in():
    if 'is_logged_in' in session and session['is_logged_in']:
        return True
    return False
